%{?mingw_package_header}

%global versionmajor 6
%global versionminor 0
%global versionsuffix 0

Name:           mingw-cximage
Version:        %{versionmajor}%{versionminor}%{versionsuffix}
Release:        %mkrel 10
Summary:        MinGW Windows CxImage manipulation library

Group:          Development/Other
License:        zlib
URL:            http://sourceforge.net/projects/cximage
Source0:        http://sourceforge.net/projects/cximage/files/%{versionmajor}.%{versionminor}%{versionsuffix}/cximage%{version}_full.7z
Source1:        cximage.pc
Patch0:         cximage-6.0.0-disable-some-formats.patch
Patch1:         cximage-6.0.0-std_min_max.patch
Patch2:         cximage-6.0.0-fix-include-name.patch
BuildArch:      noarch

BuildRequires:  mingw32-filesystem >= 95
BuildRequires:  mingw32-gcc
BuildRequires:  mingw32-jasper
BuildRequires:  mingw32-libjpeg-turbo
BuildRequires:  mingw32-libpng
BuildRequires:  mingw32-libtiff
BuildRequires:  mingw32-zlib
BuildRequires:  mingw32-pkg-config

BuildRequires:  mingw64-filesystem >= 95
BuildRequires:  mingw64-gcc
BuildRequires:  mingw64-jasper
BuildRequires:  mingw64-libjpeg-turbo
BuildRequires:  mingw64-libpng
BuildRequires:  mingw64-libtiff
BuildRequires:  mingw64-zlib
BuildRequires:  mingw64-pkg-config

BuildRequires:  p7zip


%description
CxImage is a C++ image processing library. It can load, save, display,
transform images in a very simple and fast way, with transparency, multiple
layers and selections, support for BMP GIF JPG PNG MNG TIF ICO TGA PCX J2K
JBG RAS PNM RAW PSD.


# Mingw32
%package -n mingw32-cximage
Summary: MinGW Windows CxImage manipulation library

%description -n mingw32-cximage
Cross compiled CxImage library.

%package -n mingw32-cximage-static
Summary: MinGW Windows CxImage manipulation static library
Requires: mingw32-cximage = %{version}-%{release}

%description -n mingw32-cximage-static
Cross compiled static CxImage library.

# Mingw64
%package -n mingw64-cximage
Summary: MinGW Windows CxImage manipulation library

%description -n mingw64-cximage
MinGW Windows CxImage library.

%package -n mingw64-cximage-static
Summary: MinGW Windows CxImage manipulation static library
Requires: mingw64-cximage = %{version}-%{release}

%description -n mingw64-cximage-static
Cross compiled static CxImage library.

%{?mingw_debug_package}


%prep
rm -rf %{name}-%{version}
mkdir %{name}-%{version}
pushd %{name}-%{version}
7za x %{SOURCE0}
%patch0 -p1
%patch1 -p1
%patch2 -p1
popd

%setup -q -T -D -n %{name}-%{version}


%build
%global cximage_cppflags -D_USRDLL -D_USRCxImageCrtDll -DCxImageCrtDll_EXPORTS
%global cximage32_pkg_flags $(%{mingw32_pkg_config} --cflags --libs libpng16 zlib)
%global cximage64_pkg_flags $(%{mingw64_pkg_config} --cflags --libs libpng16 zlib)
%global cximage32_ldflags -lgdi32 -lws2_32 -ljpeg -ltiff -ljasper
%global cximage64_ldflags -lgdi32 -lws2_32 -ljpeg -ltiff -ljasper

mkdir build_win32
pushd build_win32
%{mingw32_cxx} %{mingw32_cflags} %{cximage_cppflags} \
    -shared -o libcximage.dll -Wl,--out-implib,libcximage.dll.a \
    ../CxImage/*.cpp ../CxImage/CxImageDLL/CxImageCrtDll.cpp \
    %{cximage32_ldflags} %{cximage32_pkg_flags}
%{mingw32_cxx} %{mingw32_cflags} %{cximage_cppflags} \
    -c ../CxImage/*.cpp ../CxImage/CxImageDLL/CxImageCrtDll.cpp \
    %{cximage32_ldflags} %{cximage32_pkg_flags}
%{mingw32_ar} -cru libcximage.a *.o
popd

mkdir build_win64
pushd build_win64
%{mingw64_cxx} %{mingw64_cflags} %{cximage_cppflags} \
    -shared -o libcximage.dll -Wl,--out-implib,libcximage.dll.a \
    ../CxImage/*.cpp ../CxImage/CxImageDLL/CxImageCrtDll.cpp \
    %{cximage64_ldflags} %{cximage64_pkg_flags}
%{mingw64_cxx} %{mingw64_cflags} %{cximage_cppflags} \
    -c ../CxImage/*.cpp ../CxImage/CxImageDLL/CxImageCrtDll.cpp \
    %{cximage64_ldflags} %{cximage64_pkg_flags}
%{mingw64_ar} -cru libcximage.a *.o
popd


%install
install -d $RPM_BUILD_ROOT/%{mingw32_bindir}
install -d $RPM_BUILD_ROOT/%{mingw32_libdir}/pkgconfig
install -m0644 %{SOURCE1} $RPM_BUILD_ROOT/%{mingw32_libdir}/pkgconfig
sed -i s!@PREFIX@!%{mingw32_prefix}!g $RPM_BUILD_ROOT/%{mingw32_libdir}/pkgconfig/cximage.pc
install -m0644 build_win32/libcximage.dll $RPM_BUILD_ROOT/%{mingw32_bindir}/libcximage.dll
install -m0644 build_win32/libcximage.dll.a $RPM_BUILD_ROOT/%{mingw32_libdir}/libcximage.dll.a
install -m0644 build_win32/libcximage.a $RPM_BUILD_ROOT/%{mingw32_libdir}/libcximage.a
install -d $RPM_BUILD_ROOT/%{mingw32_includedir}/CxImage/
install -m0644 CxImage/*.h $RPM_BUILD_ROOT/%{mingw32_includedir}/CxImage/

install -d $RPM_BUILD_ROOT/%{mingw64_bindir}
install -d $RPM_BUILD_ROOT/%{mingw64_libdir}/pkgconfig
install -m0644 %{SOURCE1} $RPM_BUILD_ROOT/%{mingw64_libdir}/pkgconfig
sed -i s!@PREFIX@!%{mingw64_prefix}!g $RPM_BUILD_ROOT/%{mingw64_libdir}/pkgconfig/cximage.pc
install -m0644 build_win64/libcximage.dll $RPM_BUILD_ROOT/%{mingw64_bindir}/libcximage.dll
install -m0644 build_win64/libcximage.dll.a $RPM_BUILD_ROOT/%{mingw64_libdir}/libcximage.dll.a
install -m0644 build_win64/libcximage.a $RPM_BUILD_ROOT/%{mingw64_libdir}/libcximage.a
install -d $RPM_BUILD_ROOT/%{mingw64_includedir}/CxImage/
install -m0644 CxImage/*.h $RPM_BUILD_ROOT/%{mingw64_includedir}/CxImage/


%files -n mingw32-cximage
%doc CxImage/license.txt
%{mingw32_bindir}/libcximage.dll
%{mingw32_includedir}/CxImage/
%{mingw32_libdir}/libcximage.dll.a
%{mingw32_libdir}/pkgconfig/cximage.pc

%files -n mingw32-cximage-static
%{mingw32_libdir}/libcximage.a

%files -n mingw64-cximage
%doc CxImage/license.txt
%{mingw64_bindir}/libcximage.dll
%{mingw64_includedir}/CxImage/
%{mingw64_libdir}/libcximage.dll.a
%{mingw64_libdir}/pkgconfig/cximage.pc

%files -n mingw64-cximage-static
%{mingw64_libdir}/libcximage.a




%changelog
* Sun Sep 22 2013 neoclust <neoclust> 600-10.mga4
+ Revision: 483501
- imported package mingw-cximage


* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 600-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild
- Adjust name of libpng .pc file as it changed with 1.6

* Sat Jul 13 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 600-9
- Rebuild against libpng 1.6

* Sun Jan 27 2013 Erik van Pienbroek <epienbro@fedoraproject.org> - 600-8
- Rebuild against mingw-gcc 4.8 (win64 uses SEH exceptions now)

* Sat Aug 25 2012 Erik van Pienbroek <epienbro@fedoraproject.org> - 6.0.0-7
- Rebuild against latest libtiff

* Sat Jun  9 2012 Marc-André Lureau <marcandre.lureau@redhat.com> - 6.0.0-6
- Fix pkg-config --static flags

* Mon May 28 2012 Marc-André Lureau <marcandre.lureau@redhat.com> - 6.0.0-5
- Added license.txt as doc, as pointed out in rhbz#820729

* Tue May 22 2012 Marc-André Lureau <marcandre.lureau@redhat.com> - 6.0.0-4
- Fixed issues reviewed by Erik van Pienbroek in rhbz#820729

* Thu May 10 2012 Marc-André Lureau <marcandre.lureau@redhat.com> - 6.0.0-3
- Update to latest Fedora mingw64 guidelines, clean-up
- Add debug package and static library building

* Thu Feb 23 2012 Christophe Fergeau <cfergeau@redhat.com> - 6.0.0-2
- Added 64 bit support

* Wed Feb 22 2012 Christophe Fergeau <cfergeau@redhat.com> - 6.0.0-1
- Initial mingw build of CxImage
